Index: main/waeup.kwarapoly/trunk/src/waeup/kwarapoly/applicants/utils.py
===================================================================
--- main/waeup.kwarapoly/trunk/src/waeup/kwarapoly/applicants/utils.py	(revision 10132)
+++ main/waeup.kwarapoly/trunk/src/waeup/kwarapoly/applicants/utils.py	(revision 10133)
@@ -32,7 +32,9 @@
 
     APP_TYPES_DICT = {
-        'prend': ['Pre-ND Programme', 'RP'],
-        'hnd': ['HND Programmes', 'hnd'],
-        'nd': ['ND Programmes', 'nd'],
+        'rmd': ['Remedial Programme', 'RP'],
+        'hndft': ['HND Full-Time Programmes', 'HNDFT'],
+        'hndpt': ['HND Part-Time Programmes', 'HNDPT'],
+        'ndft': ['ND Full-Time Programmes', 'NDFT'],
+        'ndpt': ['ND Part-Time Programmes', 'NDPT'],
         'putme': ['Post-UTME Screening Exercise', 'PUTME'],
         'app': ['General Studies', 'APP'],

Index: main/waeup.kwarapoly/trunk/src/waeup/kwarapoly/applicants/tests/test_browser.py
===================================================================
--- main/waeup.kwarapoly/trunk/src/waeup/kwarapoly/applicants/tests/test_browser.py	(revision 10132)
+++ main/waeup.kwarapoly/trunk/src/waeup/kwarapoly/applicants/tests/test_browser.py	(revision 10133)
@@ -53,23 +53,23 @@
         setSite(app)
 
-        # Add nd applicants container
-        self.ndcontainer = ApplicantsContainer()
-        self.ndcontainer.mode = 'create'
-        self.ndcontainer.code = u'nd2011'
-        self.ndcontainer.prefix = u'nd'
-        self.ndcontainer.application_category = u'nd'
-        self.ndcontainer.year = 2011
-        self.ndcontainer.application_fee = 300.0
-        self.ndcontainer.title = u'This is the nd2011 container'
-        self.app['applicants']['nd2011'] = self.ndcontainer
+        # Add ndft applicants container
+        self.ndftcontainer = ApplicantsContainer()
+        self.ndftcontainer.mode = 'create'
+        self.ndftcontainer.code = u'ndft2011'
+        self.ndftcontainer.prefix = u'ndft'
+        self.ndftcontainer.application_category = u'ndft'
+        self.ndftcontainer.year = 2011
+        self.ndftcontainer.application_fee = 300.0
+        self.ndftcontainer.title = u'This is the ndft2011 container'
+        self.app['applicants']['ndft2011'] = self.ndftcontainer
 
         delta = datetime.timedelta(days=10)
-        self.ndcontainer.startdate = datetime.datetime.now(pytz.utc) - delta
-        self.ndcontainer.enddate = datetime.datetime.now(pytz.utc) + delta
+        self.ndftcontainer.startdate = datetime.datetime.now(pytz.utc) - delta
+        self.ndftcontainer.enddate = datetime.datetime.now(pytz.utc) + delta
 
         # Populate university
         self.certificate = createObject('waeup.Certificate')
         self.certificate.code = 'CERT1'
-        self.certificate.application_category = 'nd'
+        self.certificate.application_category = 'ndft'
         self.certificate.start_level = 100
         self.certificate.end_level = 500
@@ -81,13 +81,13 @@
 
         # Add (customized) applicants
-        ndapplicant = createObject(u'waeup.Applicant')
-        ndapplicant.firstname = u'Anna'
-        ndapplicant.lastname = u'Post'
-        self.app['applicants']['nd2011'].addApplicant(ndapplicant)
-        self.ndapplication_number = ndapplicant.application_number
-        self.ndapplicant = self.app['applicants']['nd2011'][
-            self.ndapplication_number]
-        self.ndapplicant_path = ('http://localhost/app/applicants/nd2011/%s'
-            % self.ndapplication_number)
+        ndftapplicant = createObject(u'waeup.Applicant')
+        ndftapplicant.firstname = u'Anna'
+        ndftapplicant.lastname = u'Post'
+        self.app['applicants']['ndft2011'].addApplicant(ndftapplicant)
+        self.ndftapplication_number = ndftapplicant.application_number
+        self.ndftapplicant = self.app['applicants']['ndft2011'][
+            self.ndftapplication_number]
+        self.ndftapplicant_path = ('http://localhost/app/applicants/ndft2011/%s'
+            % self.ndftapplication_number)
 
         self.browser = Browser()
@@ -111,26 +111,26 @@
 
     def test_manage_and_view_applicant(self):
         # Managers can manage nd applicants.
         self.browser.addHeader('Authorization', 'Basic mgr:mgrpw')
-        self.browser.open(self.ndapplicant_path)
+        self.browser.open(self.ndftapplicant_path)
         self.assertEqual(self.browser.headers['Status'], '200 Ok')
         self.assertTrue("'O' Level" in self.browser.contents)
         self.assertFalse("Higher" in self.browser.contents)
-        self.browser.open(self.ndapplicant_path + '/manage')
+        self.browser.open(self.ndftapplicant_path + '/manage')
         self.assertEqual(self.browser.headers['Status'], '200 Ok')
         self.assertTrue("'O' Level" in self.browser.contents)
         self.assertTrue("Higher" in self.browser.contents)
-        self.browser.open(self.ndapplicant_path + '/edit')
+        self.browser.open(self.ndftapplicant_path + '/edit')
         self.assertEqual(self.browser.headers['Status'], '200 Ok')
         self.assertTrue("'O' Level" in self.browser.contents)
         self.assertFalse("Higher" in self.browser.contents)
-        self.browser.open(self.ndapplicant_path + '/application_slip.pdf')
+        self.browser.open(self.ndftapplicant_path + '/application_slip.pdf')
         self.assertEqual(self.browser.headers['Status'], '200 Ok')
-        # Now we turn the nd applicant into an hnd applicant.
-        self.ndapplicant.applicant_id = u'hnd_anything'
-        self.browser.open(self.ndapplicant_path)
+        # Now we turn the ndft applicant into an hndft applicant.
+        self.ndftapplicant.applicant_id = u'hndft_anything'
+        self.browser.open(self.ndftapplicant_path)
         self.assertTrue("Higher" in self.browser.contents)
         self.assertTrue("'O' Level" in self.browser.contents)
-        self.browser.open(self.ndapplicant_path + '/edit')
+        self.browser.open(self.ndftapplicant_path + '/edit')
         self.assertTrue("Higher" in self.browser.contents)
         self.assertTrue("'O' Level" in self.browser.contents)
@@ -111,26 +111,26 @@
 
     def test_manage_and_view_applicant(self):
-        # Managers can manage nd applicants.
+        # Managers can manage ndft applicants.
         self.browser.addHeader('Authorization', 'Basic mgr:mgrpw')